==> business_lite-7.x-1.0.tar.gz: business_lite/template.php <==
<?php


function business_lite_preprocess_page(&$vars) {
  // Useful for devel default banners, remove before commit
  //   variable_del('theme_marinelli_first_install');
  // Chcek if is first setup of marinelli and install banners.
  if (variable_get('theme_business_lite_first_install', TRUE)) {
    include_once('theme-settings.php');
    _business_lite_install();
  }
  //to print the banners
  $banners = business_lite_show_banners();
  $vars['banner'] = $banners;
  if(drupal_is_front_page()){
    drupal_add_js(path_to_theme() .'/js/slide.js', 'file');
    
  }
  //$vars['main_links_tree'] = menu_tree(variable_get('menu_main_links_source', 'main-menu'));
  //print render ( $vars['main_links_tree']);
}

/**
 *
 * @return <array>
 *    html markup to show banners
 */
function business_lite_show_banners() {
  $banners = business_lite_get_banners(FALSE);
  //print_r($banners);
 // print_r($banners);
  $output = ' <div id="orbitDemo">';
  
  for($i=0;$i<count($banners);$i++){
  /*  $output .= '<a href="' . $banners[$i]['image_url'] . '" >';
    $output .= '<img src="' . file_create_url($banners[$i]['image_path']) . '" >';
    $output .= '</a>'; */ 
    $output .= l('<img class="img-sl" src="' . file_create_url($banners[$i]['image_path']) . '" alt="slider image' . $i . '" />', $banners[$i]['image_url'],array('html' => TRUE));
  }  
  $output .= '</div>';
  //print l('sdfsd','dfsdf');
  return $output;
}


/**
 * Get banner settings.
 *
 * @param <bool> $all
 *    Return all banners or only active.
 *
 * @return <array>
 *    Settings information
 */
function business_lite_get_banners($all = TRUE) {
  // Get all banners
  $banners = variable_get('theme_business_lite_banner_settings', array());

  // Create list of banner to return
  $banners_value = array();
  foreach ($banners as $banner) {     
      $banners_value[] = $banner;   
  }

  // Sort image by weight
  //usort($banners_value, 'drupal_sort_weight');

  return $banners_value;
}

/**
 * Set banner settings.
 *
 * @param <array> $value
 *    Settings to save
 */
function business_lite_set_banners($value) {
  variable_set('theme_business_lite_banner_settings', $value);
}

function business_lite_form_alter(&$form, &$form_state, $form_id) {
  if ($form_id == 'search_block_form') {
  		
  		$form['search_block_form']['#value'] = 'Search';  // define size of the textfield
  		$form['actions']['submit']['#value'] = ''; // Change the text on the submit button
  		$form['actions']['submit'] = array('#type' => 'image_button', '#src' => base_path() . path_to_theme() . '/images/magnify.png');
  		
  		$form['search_block_form']['#attributes']['onblur'] = "if (this.value == '') {this.value = 'Search';}";
  		$form['search_block_form']['#attributes']['onfocus'] = "if (this.value == 'Search') {this.value = '';}";
  }
}
/*function business_lite_preprocess_page(&$vars) {
  $vars['main_links_tree'] = menu_tree(variable_get('menu_main_links_source', 'main-menu'));
}*/

==> business_lite-7.x-1.1.tar.gz: business_lite/template.php <==
<?php


function business_lite_preprocess_page(&$vars) {
  // Useful for devel default banners, remove before commit
  //   variable_del('theme_marinelli_first_install');
  // Chcek if is first setup of marinelli and install banners.
  if (variable_get('theme_business_lite_first_install', TRUE)) {
    include_once('theme-settings.php');
    _business_lite_install();
  }
  //to print the banners
  $banners = business_lite_show_banners();
  $vars['banner'] = $banners;
  if(drupal_is_front_page()){
    drupal_add_js(path_to_theme() .'/js/slide.js', 'file');
    
  }
  //$vars['main_links_tree'] = menu_tree(variable_get('menu_main_links_source', 'main-menu'));
  //print render ( $vars['main_links_tree']);
}

/**
 *
 * @return <array>
 *    html markup to show banners
 */
function business_lite_show_banners() {
  $banners = business_lite_get_banners(FALSE);
  //print_r($banners);
 // print_r($banners);
  $output = ' <div id="orbitDemo">';
  
  for($i=0;$i<count($banners);$i++){
  /*  $output .= '<a href="' . $banners[$i]['image_url'] . '" >';
    $output .= '<img src="' . file_create_url($banners[$i]['image_path']) . '" >';
    $output .= '</a>'; */ 
    $output .= l('<img class="img-sl" src="' . file_create_url($banners[$i]['image_path']) . '" alt="slider image' . $i . '" />', $banners[$i]['image_url'],array('html' => TRUE));
  }  
  $output .= '</div>';
  //print l('sdfsd','dfsdf');
  return $output;
}


/**
 * Get banner settings.
 *
 * @param <bool> $all
 *    Return all banners or only active.
 *
 * @return <array>
 *    Settings information
 */
function business_lite_get_banners($all = TRUE) {
  // Get all banners
  $banners = variable_get('theme_business_lite_banner_settings', array());

  // Create list of banner to return
  $banners_value = array();
  foreach ($banners as $banner) {     
      $banners_value[] = $banner;   
  }

  // Sort image by weight
  //usort($banners_value, 'drupal_sort_weight');

  return $banners_value;
}

/**
 * Set banner settings.
 *
 * @param <array> $value
 *    Settings to save
 */
function business_lite_set_banners($value) {
  variable_set('theme_business_lite_banner_settings', $value);
}

function business_lite_form_alter(&$form, &$form_state, $form_id) {
  if ($form_id == 'search_block_form') {
  		
  		$form['search_block_form']['#attributes']['placeholder'] = t('Search');
  		//$form['search_block_form']['#value'] = 'Search';  // define size of the textfield
  		$form['actions']['submit']['#value'] = ''; // Change the text on the submit button
  		$form['actions']['submit'] = array('#type' => 'image_button', '#src' => base_path() . path_to_theme() . '/images/magnify.png');
  		
  		/*$form['search_block_form']['#attributes']['onblur'] = "if (this.value == '') {this.value = 'Search';}";
  		$form['search_block_form']['#attributes']['onfocus'] = "if (this.value == 'Search') {this.value = '';}";*/
  }
}
/*function business_lite_preprocess_page(&$vars) {
  $vars['main_links_tree'] = menu_tree(variable_get('menu_main_links_source', 'main-menu'));
}*/
